==> haskell-hs-bibutils-6.10.0.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-5PK4kuDXCE8LMJGuibNagf
key:                  hs-bibutils-6.10.0.0-5PK4kuDXCE8LMJGuibNagf
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  e93517d2bf076b98056539dfcc403015
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-8.10.3/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hs-bibutils-6.10.0.0
hs-libraries:         HShs-bibutils-6.10.0.0-5PK4kuDXCE8LMJGuibNagf
includes:             bibutils.h
depends:              base-4.14.1.0 syb-0.7.2.1-7YteKEvijmt5wSroPLHLQq
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-6.10.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-Bna12vsGG1VFcEVOOXVetg
key:                  hs-bibutils-6.10.0.0-Bna12vsGG1VFcEVOOXVetg
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  80dcc3b8aad0fedbc1b32328a765fbb5
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hs-bibutils-6.10.0.0
hs-libraries:         HShs-bibutils-6.10.0.0-Bna12vsGG1VFcEVOOXVetg
includes:             bibutils.h
depends:              base-4.14.1.0 syb-0.7.2.1-3NRuID5KtwUDKtTIjLYVTX
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
